7032417: Fix for 6981922 does not address multiple VM case
authorasaha
Wed, 20 Jul 2011 09:01:04 -0700
changeset 10909 745b87239228
parent 10908 cd144dc30fbe
child 10910 5ad2744fc78a
7032417: Fix for 6981922 does not address multiple VM case Reviewed-by: michaelm
jdk/src/share/classes/sun/net/ResourceManager.java
--- a/jdk/src/share/classes/sun/net/ResourceManager.java	Tue Jul 19 11:04:28 2011 -0700
+++ b/jdk/src/share/classes/sun/net/ResourceManager.java	Wed Jul 20 09:01:04 2011 -0700
@@ -41,13 +41,14 @@
 
     /* default maximum number of udp sockets per VM
      * when a security manager is enabled.
      * The default is 1024 which is high enough to be useful
      * but low enough to be well below the maximum number
-     * of port numbers actually available on all OSes for
-     * such sockets (5000 on some versions of windows)
+     * of port numbers actually available on all OSes
+     * when multiplied by the maximum feasible number of VM processes
+     * that could practically be spawned.
      */
 
-    private static final int DEFAULT_MAX_SOCKETS = 1024;
+    private static final int DEFAULT_MAX_SOCKETS = 25;
     private static final int maxSockets;
     private static final AtomicInteger numSockets;
@@ -41,13 +41,14 @@
     /* default maximum number of udp sockets per VM
      * when a security manager is enabled.
-     * The default is 1024 which is high enough to be useful
+     * The default is 25 which is high enough to be useful
      * but low enough to be well below the maximum number